USE AdventureWorks2012;
GO

--DROP TABLE BitsExecutionLogging
CREATE TABLE BitsExecutionLogging
(
	Id int identity(1,1)
	, ServerExecutionID int
	, StartDate date
	, StartTime time
	, EndDate date
	, EndTime time
	, Package nvarchar(128) 
	, TableName sysname
	, InitialRecordCount int
	, FinalRecordCount int
	, InsertedRecordCount int
);

GO 

--DROP PROCEDURE usp_Insert_BitsExecutionLogging
CREATE PROCEDURE usp_Insert_BitsExecutionLogging
	@StartDate date
	, @StartTime time
	, @Package nvarchar(128) 
	, @TableName sysname
	, @ID int OUTPUT
	, @ServerExecutionID int
AS
	SET NOCOUNT ON;
	SET XACT_ABORT ON;

	-- Get initial rowcount of processed table:
	DECLARE @Count int;
	DECLARE @SQL NVARCHAR(256) = 'SELECT @Count = COUNT(*) FROM ';
	SET @SQL = @SQL + @TableName;
	EXEC sp_executesql @SQL, N'@Count int OUTPUT', @Count OUTPUT;	
	
	-- Insert monitoring record:
	INSERT BitsExecutionLogging (StartDate, StartTime, Package, TableName, ServerExecutionID, InitialRecordCount)
	VALUES (@StartDate, @StartTime, @Package, @TableName, @ServerExecutionID, @Count);

	SELECT @ID = SCOPE_IDENTITY();




GO

-- DROP PROCEDURE usp_Update_BitsExecutionLogging
CREATE PROCEDURE usp_Update_BitsExecutionLogging
	@EndDate date
	, @EndTime time
	, @ID int
	, @InsertedRecordCount int
	, @tableName sysname
AS
	SET NOCOUNT ON;
	SET XACT_ABORT ON;

	-- Get initial rowcount of processed table:
	DECLARE @Count int;
	DECLARE @SQL NVARCHAR(256) = 'SELECT @Count = COUNT(*) FROM ';
	SET @SQL = @SQL + @TableName;
	EXEC sp_executesql @SQL, N'@Count int OUTPUT', @Count OUTPUT;	

	UPDATE BitsExecutionLogging
	SET EndDate = @EndDate, EndTime = @EndTime, InsertedRecordCount = @InsertedRecordCount, FinalRecordCount = @Count
	WHERE Id = @ID;