--see http://msdn.microsoft.com/en-us/library/hh479592.aspx

--[catalog].[operations]: All operations in SSISDB Catalog
SELECT [operation_id]
      ,[operation_type] -- 101=delpoy project, 106=restore project, 200=create execution, 300=validate project, 1000=configure catalog, ...
      ,[created_time]
      ,[object_type]
      ,[object_id]
      ,[object_name]
      ,[status] -- 2=running, 7=succeeded, ...
      ,[start_time]
      ,[end_time]
      ,[caller_sid]
      ,[caller_name]
      ,[process_id]
      ,[stopped_by_sid]
      ,[stopped_by_name]
      ,[server_name]
      ,[machine_name]
FROM [SSISDB].[catalog].[operations]
WHERE start_time > GETDATE() - 1;

--[catalog].[executions]: Displays the instances of package execution in the Integration Services catalog.
--Packages that are executed with the Execute Package task run in the same instance of execution as the parent package.
--uses row level security
SELECT [execution_id]
      ,[folder_name]
      ,[project_name]
      ,[package_name]
      ,[reference_id] -- referenced environment
      ,[reference_type] -- 'A' = absolute reference, 'R' = relative reference
      ,[environment_folder_name]
      ,[environment_name]
      --,[project_lsn] -- version of the project
      --,[executed_as_sid]
      ,[executed_as_name]
      ,[use32bitruntime]
      ,[operation_type] -- validate, execute, stop, ...
      --,[created_time]
      --,[object_type] -- 30 = package, 20 = project
      --,[object_id]
      ,CASE	WHEN [status] = 1 THEN 'Created'
			WHEN [status] = 2 THEN 'Running'
			WHEN [status] = 3 THEN 'Cancelled'
			WHEN [status] = 4 THEN 'Failed'
			WHEN [status] = 5 THEN 'Pending'
			WHEN [status] = 6 THEN 'EndedUnexpectedly'
			WHEN [status] = 7 THEN 'Succeeded'
			WHEN [status] = 8 THEN 'Stopping'
			ELSE 'Completed'
		END AS [status_name]
      ,[start_time]
      --,[end_time]
	  ,DATEDIFF(s, Start_time, end_time) AS duration_in_sec
      --,[caller_sid]
      ,[caller_name]
      --,[process_id]
      --,[stopped_by_sid]
      --,[stopped_by_name]
      --,[dump_id]
      ,[server_name]
      --,[machine_name]
	  ,[total_physical_memory_kb] / (1024) AS total_physical_memory_mb-- total physical memory on the server when execution is started
      ,[available_physical_memory_kb] / (1024) AS available_physical_memory_mb -- available physical memory on the server when execution is started
      ,[total_page_file_kb] / (1024) AS total_page_file_mb -- total page memory on the server
      ,[available_page_file_kb] / (1024) AS available_page_file_mb -- available page memory on server
      ,[cpu_count]
FROM [SSISDB].[catalog].[executions]
WHERE start_time > GETDATE() - 1;


--[catalog].[executables]: This view displays a row for each executable in the specified execution.
--Executable is task added to Control Flow OR Package itself
SELECT [executable_id]
      ,[execution_id]
      ,[executable_name]
      ,[executable_guid]
      ,[package_name]
      ,[package_path]
FROM [SSISDB].[catalog].[executables]
ORDER BY execution_id DESC;

--Combined:
SELECT e.execution_id
		, e.package_name
		, t.executable_name AS Task_or_Package
FROM [SSISDB].[catalog].[executions] e
JOIN [SSISDB].[catalog].[executables] t ON e.execution_id = t.execution_id
WHERE start_time > GETDATE() - 1;

--Displays a row for each executable (task or package) that is run, including each iteration of an executable.
SELECT [statistics_id]
      ,[execution_id]
      ,[executable_id]
      ,[execution_path]
      ,[start_time]
      ,[end_time]
      ,[execution_duration]
      ,[execution_result] -- 0=succes, 1=failure, 2=completion, 3=cancelled
      ,[execution_value] -- user defined variant
FROM [SSISDB].[catalog].[executable_statistics]
WHERE start_time > GETDATE() - 1;


SELECT e.execution_id
		, e.start_time
		, e.package_name
		, t.executable_name AS Task
		, s.execution_duration / 1000 AS Duration_in_sec
FROM [SSISDB].[catalog].[executions] e
JOIN [SSISDB].[catalog].[executables] t ON e.execution_id = t.execution_id
JOIN [SSISDB].[catalog].[executable_statistics] s ON e.execution_id = s.execution_id 
												AND t.executable_id = s.executable_id
WHERE package_path like '\Package\%' --get tasks only, no packages
	AND e.start_time > GETDATE() - 1
ORDER BY Duration_in_sec DESC;

--All failed executions with status per task:
--NB LEFT OUTER JOIN!
SELECT e.execution_id
		, e.start_time
		, e.package_name
		, t.executable_name AS Task_or_Package
		, CASE
			WHEN s.execution_result = 0 THEN 'Succes'
			WHEN s.execution_result = 1 THEN 'Failed'
			WHEN s.execution_result = 2 THEN 'Completed'
			WHEN s.execution_result = 3 THEN 'Cancelled'
			ELSE 'Undetermined'
			END AS Result
FROM [SSISDB].[catalog].[executions] e
LEFT JOIN [SSISDB].[catalog].[executables] t ON e.execution_id = t.execution_id
LEFT JOIN [SSISDB].[catalog].[executable_statistics] s ON e.execution_id = s.execution_id 
												AND t.executable_id = s.executable_id
WHERE e.status = 4
ORDER BY e.execution_id

--[catalog].[execution_component_phases]: Displays the time spent by a data flow component in each execution phase.
--logging should be set to performance or verbose!
SELECT [phase_stats_id]
      ,[execution_id]
      ,[package_name]
      ,[task_name]
      ,[subcomponent_name]
      ,[phase]
      ,[start_time]
      ,DATEDIFF(ms,[start_time], [end_time]) AS Duration_in_ms
      ,[execution_path]
FROM [SSISDB].[catalog].[execution_component_phases]
WHERE start_time > GETDATE() - 1
ORDER BY execution_id DESC;


--Total time spent per transformation:
SELECT package_name, task_name, subcomponent_name, execution_path,
    SUM(DATEDIFF(ms,start_time,end_time)) as active_time,
    DATEDIFF(ms,min(start_time), max(end_time)) as total_time
FROM catalog.execution_component_phases
--WHERE execution_id = 1841
GROUP BY package_name, task_name, subcomponent_name, execution_path
ORDER BY package_name, task_name, subcomponent_name, execution_path;


--This view displays a row each time a data flow component sends data to a downstream component, for a given package execution. The information in this view can be used to compute the data throughput for a component.
--Set logging to Verbose
SELECT [data_stats_id]
      ,[execution_id]
      ,[package_name]
      ,[task_name]
      ,[dataflow_path_id_string]
      ,[dataflow_path_name]
      ,[source_component_name]
      ,[destination_component_name]
      ,[rows_sent]
      ,[created_time]
      ,[execution_path]
FROM [SSISDB].[catalog].[execution_data_statistics]
WHERE created_time > getdate() - 1;


-- Total records loaded per data flow task:
-- NB naming convention!!!!
SELECT eds.[execution_id]
      ,eds.[package_name]
	  ,e.start_time
      ,[task_name]
      ,SUM([rows_sent]) AS Records_Inserted
FROM [SSISDB].[catalog].[execution_data_statistics] eds
JOIN [SSISDB].[catalog].[executions] e ON e.execution_id = eds.execution_id 
WHERE e.start_time > getdate() - 1
	AND destination_component_name like 'OLE DB Destination%'
GROUP BY eds.execution_id, eds.package_name, e.start_time, task_name
ORDER BY execution_id, package_name, task_name;



--Displays the actual parameter values that are used by Integration Services packages during an instance of execution.
--This view displays a row for each execution parameter in the catalog. An execution parameter value is the value that is assigned to a project parameter or package parameter during a single instance of execution
SELECT e.package_name
	  ,[execution_parameter_id]
      ,p.[execution_id]
      ,p.[object_type] -- 20=project parameters, 30=package parameter, 50=pre defined system parameters
      ,[parameter_data_type]
      ,[parameter_name]
      ,[parameter_value]
      ,[sensitive]
      ,[required]
      ,[value_set]
      ,[runtime_override]
FROM [SSISDB].[catalog].[execution_parameter_values] p
JOIN [SSISDB].[catalog].[executions] e ON e.execution_id = p.execution_id
WHERE e.start_time > GETDATE() - 1
	AND p.object_type <> 50;


--[catalog].[event_messages]: shows logged runtime messages
SELECT [event_message_id]
      ,[operation_id]
      ,[message_time]
      ,[message_type]
      ,[message_source_type]
      ,[message]
      ,[extended_info_id]
      ,[package_name]
      ,[event_name]
      ,[message_source_name]
      ,[message_source_id]
      ,[subcomponent_name]
      ,[package_path]
      ,[execution_path]
      ,[threadID]
      ,[message_code]
FROM [SSISDB].[catalog].[event_messages];
--See also: catalog.operation_messages 




-- Hoeveel messages heeft Verbose logging opgeleverd? En Basic?
-- Get all messages from latest execution:
SELECT 
	event_message_id
	,MESSAGE
	,package_name
	,event_name
	,message_source_name
	,package_path
	,execution_path
	,message_type
	,message_source_type
FROM   (
       SELECT  
			em.*
       FROM    SSISDB.catalog.event_messages em
       WHERE   em.operation_id = (
								SELECT 
									MAX(execution_id)
								FROM SSISDB.catalog.executions
								)
	           AND event_name NOT LIKE '%Validate%'
       ) q
--WHERE	event_name = 'OnError'
--WHERE	package_name = 'Package.dtsx'
--WHERE execution_path LIKE '%<some executable>%'
ORDER BY message_time DESC
 