
SELECT 
	l.Package
	, e.package_name
	, l.StartDate, l.StartTime
	, CASE 
		WHEN l.EndTime IS NULL THEN 'Failure'
		ELSE 'Succes'
	  END AS Status
	, DATEDIFF(ms, l.StartTime, l.EndTime) as Duration_in_ms
	, SUM(DATEDIFF(ms, l.StartTime, l.EndTime)) OVER (PARTITION BY package_name ORDER BY StartDate ROWS BETWEEN 1 PRECEDING AND 1 PRECEDING) AS Previous_Duration
	, e.caller_name
	, e.executed_as_name
	, l.InsertedRecordCount
	, SUM(l.InsertedRecordCount) OVER (PARTITION BY l.package ORDER BY StartDate ROWS BETWEEN 1 PRECEDING AND 1 PRECEDING) AS Previous_InsertedRecordCount
FROM AdventureWorksDW2012.dbo.BitsExecutionLogging l
INNER JOIN SSISDB.catalog.executions e on l.ServerExecutionID = e.execution_id
--WHERE start_time BETWEEN @StartDate AND @EndDate
ORDER BY Starttime DESC




-- First package to run, Last package to run, overall time:
SELECT TOP 1
	package_name
	, start_time
	, end_time
	, DATEDIFF(MINUTE, start_time, end_time) as duration_in_minutes
FROM SSISDB.catalog.executions
WHERE start_time >= DATEADD(HH, 21, CONVERT(datetime, CONVERT(date, GETUTCDATE() - 1)))  -- 9 PM last night
ORDER BY start_time ASC	

SELECT TOP 1
	package_name
	, start_time
	, end_time
	, DATEDIFF(MINUTE, start_time, end_time) as duration_in_minutes
FROM SSISDB.catalog.executions
ORDER BY start_time DESC

SELECT
	DATEDIFF(MINUTE
				,(SELECT TOP 1
					start_time
				FROM SSISDB.catalog.executions
				WHERE start_time >= DATEADD(HH, 21, CONVERT(datetime, CONVERT(date, GETUTCDATE() - 1)))  -- 9 PM last night
				ORDER BY start_time ASC)
				,(SELECT TOP 1
					start_time
				FROM SSISDB.catalog.executions
				ORDER BY start_time DESC)) AS runtime_in_minutes


--Package detail:
SELECT 
	package_name
	, StartDate
	, CASE 
		WHEN status = 7 THEN 'Succes'
		WHEN status = 4 THEN 'Failure'
	  END AS Status
	, DATEDIFF(ms, StartTime, EndTime) as Duration_in_ms
	, SUM(DATEDIFF(ms, StartTime, EndTime)) OVER (PARTITION BY package_name ORDER BY StartDate ROWS BETWEEN 1 PRECEDING AND 1 PRECEDING) AS Previous_Duration
	, caller_name
	, executed_as_name
	, InsertedRecordCount
	, SUM(InsertedRecordCount) OVER (PARTITION BY package_name ORDER BY StartDate ROWS BETWEEN 1 PRECEDING AND 1 PRECEDING) AS Previous_InsertedRecordCount
	, environment_name
	, environment_folder_name
FROM AdventureWorksDW2012.dbo.BitsExecutionLogging l
JOIN SSISDB.catalog.executions e on l.ServerExecutionID = e.execution_id
WHERE package = @Package
ORDER BY StartDate DESC


-- failed execution with status per task
SELECT e.execution_id
		, e.start_time
		, e.package_name
		, t.executable_name AS Task_or_Package
		, CASE
			WHEN s.execution_result = 0 THEN 'Succes'
			WHEN s.execution_result = 1 THEN 'Failed'
			WHEN s.execution_result = 2 THEN 'Completed'
			WHEN s.execution_result = 3 THEN 'Cancelled'
			ELSE 'Undetermined'
			END AS Result
		, package_path
FROM AdventureWorksDW2012.dbo.BitsExecutionLogging l
JOIN [SSISDB].[catalog].[executions] e ON l.ServerExecutionID = e.execution_id
LEFT JOIN [SSISDB].[catalog].[executables] t ON e.execution_id = t.execution_id
LEFT JOIN [SSISDB].[catalog].[executable_statistics] s ON e.execution_id = s.execution_id 
												AND t.executable_id = s.executable_id
WHERE s.execution_result = 1 AND l.package = @Package AND package_path like '\Package\%' --get tasks only, no packages
ORDER BY e.execution_id